@@ -42,6 +42,29 @@ class TestJsonLogger(unittest.TestCase):
 
         self.assertEqual(logJson["message"], msg)
 
+    def testRenameBaseField(self):
+        fr = jsonlogger.JsonFormatter(rename_fields={'message': '@message'})
+        self.logHandler.setFormatter(fr)
+
+        msg = "testing logging format"
+        self.logger.info(msg)
+        logJson = json.loads(self.buffer.getvalue())
+
+        self.assertEqual(logJson["@message"], msg)
+
+    def testAddStaticFields(self):
+        fr = jsonlogger.JsonFormatter(static_fields={'log_stream': 'kafka'})
+
+        self.logHandler.setFormatter(fr)
+
+        msg = "testing static fields"
+        self.logger.info(msg)
+        logJson = json.loads(self.buffer.getvalue())
+
+        self.assertEqual(logJson["log_stream"], "kafka")
+        self.assertEqual(logJson["message"], msg)
+
+
     def testFormatKeys(self):
         supported_keys = [
             'asctime',
